@@ -15,6 +15,7 @@ from typing import (
     Any,
     cast,
 )
+import warnings
 
 
 import affine
@@ -81,19 +82,32 @@ def prepare_items(
         asset_ids = list(max((item["assets"] for item in items), key=len))
     elif isinstance(assets, AbstractSet):
         allowed_mimetypes = [Mimetype.from_str(t) for t in assets]
-        type_strs_by_id = collections.defaultdict(set)
+        type_strs_by_id: dict[str, set[Optional[str]]] = collections.defaultdict(set)
         for item in items:
             for asset_id, asset in item["assets"].items():
                 type_strs_by_id[asset_id].add(asset.get("type"))
 
         mimetypes_by_id = {
-            id: [Mimetype.from_str(t) for t in types]
+            id: [Mimetype.from_str(t) for t in types if t is not None]
             for id, types in type_strs_by_id.items()
         }
+
+        ids_without_type = [
+            id for id, mimetypes in mimetypes_by_id.items() if not mimetypes
+        ]
+        if ids_without_type:
+            warnings.warn(
+                f"You're filtering for assets that match the mimetype(s) {assets}, but since {len(ids_without_type)} "
+                f"(out of {len(type_strs_by_id)}) asset(s) have no `type` specified on any item, those will be "
+                "dropped. Consider passing a list of asset IDs instead to the `assets=` parameter.\n"
+                f"Assets with no type: {ids_without_type}",
+            )
+
         asset_ids = [
             asset_id
             for asset_id, asset_mimetypes in mimetypes_by_id.items()
-            if all(
+            if asset_mimetypes
+            and all(
                 any(
                     asset_mt.is_valid_for(allowed_mt)
                     for allowed_mt in allowed_mimetypes
@@ -110,6 +124,8 @@ def prepare_items(
 
     if len(items) == 0:
         raise ValueError("No items")
+    if len(asset_ids) == 0:
+        raise ValueError("Zero asset IDs requested")
 
     for item_i, item in enumerate(items):
         item_epsg = item["properties"].get("proj:epsg")
@@ -375,32 +391,27 @@ def to_coords(
             )
 
         transform = spec.transform
-        if transform.is_rectilinear:
-            # faster-path for rectilinear transforms: just `arange` it instead of doing the affine math
-            minx, miny, maxx, maxy = spec.bounds
-            xres, yres = spec.resolutions_xy
+        # We generate the transform ourselves in `RasterSpec`, and it's always constructed to be rectilinear.
+        # Someday, this should not always be the case, in order to support non-rectilinear data without warping.
+        assert (
+            transform.is_rectilinear
+        ), f"Non-rectilinear transform generated: {transform}"
+        minx, miny, maxx, maxy = spec.bounds
+        xres, yres = spec.resolutions_xy
 
-            if pixel_center:
-                half_xpixel, half_ypixel = xres / 2, yres / 2
-                minx, miny, maxx, maxy = (
-                    minx + half_xpixel,
-                    miny + half_ypixel,
-                    maxx + half_xpixel,
-                    maxy + half_ypixel,
-                )
+        if pixel_center:
+            half_xpixel, half_ypixel = xres / 2, yres / 2
+            minx, miny, maxx, maxy = (
+                minx + half_xpixel,
+                miny - half_ypixel,
+                maxx + half_xpixel,
+                maxy - half_ypixel,
+            )
 
-            height, width = spec.shape
-            # Wish pandas had an RangeIndex that supported floats...
-            xs = pd.Float64Index(np.linspace(minx, maxx, width, endpoint=False))
-            ys = pd.Float64Index(np.linspace(maxy, miny, height, endpoint=False))
-        else:
-            height, width = spec.shape
-            if pixel_center:
-                xs, _ = transform * (np.arange(width) + 0.5, np.zeros(width) + 0.5)
-                _, ys = transform * (np.zeros(height) + 0.5, np.arange(height) + 0.5)
-            else:
-                xs, _ = transform * (np.arange(width), np.zeros(width))
-                _, ys = transform * (np.zeros(height), np.arange(height))
+        height, width = spec.shape
+        # Wish pandas had an RangeIndex that supported floats...
+        xs = pd.Float64Index(np.linspace(minx, maxx, width, endpoint=False))
+        ys = pd.Float64Index(np.linspace(maxy, miny, height, endpoint=False))
 
         coords["x"] = xs
         coords["y"] = ys
@@ -459,13 +470,9 @@ def to_coords(
 
     if band_coords:
         flattened_metadata_by_asset = [
-            accumulate_metadata.accumulate_metadata(
+            accumulate_metadata.accumulate_metadata_only_allsame(
                 (item["assets"].get(asset_id, {}) for item in items),
                 skip_fields={"href", "type", "roles"},
-                only_allsame="ignore-missing",
-                # ^ NOTE: we `ignore-missing` because I've observed some STAC collections
-                # missing `eo:bands` on some items.
-                # xref https://github.com/sat-utils/sat-api/issues/229
             )
             for asset_id in asset_ids
         ]
@@ -496,7 +503,7 @@ def to_coords(
                 # skip_fields={"href", "title", "description", "type", "roles"},
             )
         )
-        if any(d for d in eo_by_asset):
+        if any(eo_by_asset):
             coords.update(
                 accumulate_metadata.metadata_to_coords(
                     eo_by_asset,
