@@ -33,9 +33,9 @@ class Reader(Pickleable, Protocol):
         spec: RasterSpec,
         resampling: Resampling,
         dtype: np.dtype,
-        fill_value: Optional[Union[int, float]] = np.nan,
-        rescale: bool = True,
-        gdal_env: Optional[LayeredEnv] = None,
+        fill_value: Union[int, float],
+        rescale: bool,
+        gdal_env: Optional[LayeredEnv],
         errors_as_nodata: Tuple[Exception, ...] = (),
     ) -> None:
         """
@@ -113,13 +113,11 @@ class FakeReader:
     or inherent to the dask graph.
     """
 
-    def __init__(self, *, url: str, spec: RasterSpec, **kwargs) -> None:
-        pass
-        # self.url = url
-        # self.spec = spec
+    def __init__(self, *, dtype: np.dtype, **kwargs) -> None:
+        self.dtype = dtype
 
     def read(self, window: Window, **kwargs) -> np.ndarray:
-        return np.random.random((window.height, window.width))
+        return np.random.random((window.height, window.width)).astype(self.dtype)
 
     def close(self) -> None:
         pass
