@@ -19,10 +19,12 @@ from typing import (
     cast,
 )
 
+possible_problems: list[str] = []
+
 try:
-    from satstac import Item as SatstacItem
-    from satstac import ItemCollection as SatstacItemCollection
-except ImportError:
+    from satstac.item import Item as SatstacItem
+    from satstac.itemcollection import ItemCollection as SatstacItemCollection
+except ImportError as e:
 
     class SatstacItem:
         _data: ItemDict
@@ -31,11 +33,20 @@ except ImportError:
         def __iter__(self) -> Iterator[SatstacItem]:
             ...
 
+    if not isinstance(e, ModuleNotFoundError):
+        possible_problems.append(
+            "Your version of `satstac` is too old (or new) for stackstac. "
+            "`satstac.Item` and `satstac.ItemCollection` aren't supported "
+            f"because they could not be imported: {e!r}"
+        )
+    del e
+
 
 try:
     from pystac import Catalog as PystacCatalog
     from pystac import Item as PystacItem
-except ImportError:
+    from pystac import ItemCollection as PystacItemCollection
+except ImportError as e:
 
     class PystacItem:
         def to_dict(self) -> ItemDict:
@@ -45,14 +56,20 @@ except ImportError:
         def get_all_items(self) -> Iterator[PystacItem]:
             ...
 
-
-try:
-    from pystac_client import ItemCollection as PystacClientItemCollection
-except ImportError:
-
-    class PystacClientItemCollection:
+    class PystacItemCollection:
         features: List[PystacItem]
 
+        def __iter__(self) -> Iterator[PystacItem]:
+            ...
+
+    if not isinstance(e, ModuleNotFoundError):
+        possible_problems.append(
+            "Your version of `pystac` is too old (or new) for stackstac. "
+            "`pystac.Item`, `pystac.ItemCollection`, and `pystac.Catalog` aren't supported "
+            f"because they could not be imported: {e!r}"
+        )
+    del e
+
 
 class EOBand(TypedDict, total=False):
     name: str
@@ -113,7 +130,7 @@ ItemSequence = Sequence[ItemDict]
 
 ItemIsh = Union[SatstacItem, PystacItem, ItemDict]
 ItemCollectionIsh = Union[
-    SatstacItemCollection, PystacCatalog, PystacClientItemCollection, ItemSequence
+    SatstacItemCollection, PystacCatalog, PystacItemCollection, ItemSequence
 ]
 
 
@@ -122,7 +139,7 @@ def items_to_plain(items: Union[ItemCollectionIsh, ItemIsh]) -> ItemSequence:
     Convert something like a collection/Catalog of STAC items into a list of plain dicts
 
     Currently works on ``satstac.ItemCollection``, ``pystac.Catalog`` (inefficiently),
-    ``pystac_client.ItemCollection`` (inefficiently), and plain Python lists-of-dicts.
+    ``pystac.ItemCollection`` (inefficiently), and plain Python lists-of-dicts.
     """
 
     if isinstance(items, dict):
@@ -153,7 +170,14 @@ def items_to_plain(items: Union[ItemCollectionIsh, ItemIsh]) -> ItemSequence:
     if isinstance(items, PystacCatalog):
         return [item.to_dict() for item in items.get_all_items()]
 
-    if isinstance(items, PystacClientItemCollection):
-        return [item.to_dict() for item in items.features]
+    if isinstance(items, PystacItemCollection):
+        return [item.to_dict() for item in items]
 
-    raise TypeError(f"Unrecognized STAC collection type {type(items)}: {items!r}")
+    raise TypeError(
+        f"Unrecognized STAC collection type {type(items)}: {items!r}"
+        + (
+            "\n".join(["\nPossible problems:"] + possible_problems)
+            if possible_problems
+            else ""
+        )
+    )
